@@ -1,4 +1,4 @@
-from .driver import Driver
+from .driver import Driver, DRIVER_TIMEOUT
 from .undetected_chrome_driver import UndetectedChromeDriver
 from .firefox_driver import FirefoxDriver
 from .chrome_driver import ChromeDriver
